@@ -22,9 +22,7 @@ signals:
 public:
     HttpFetcher ();
 
-    bool busy () const;
     void fetch (const QString& url);
-    void reset ();
 };
 
 
